@@ -23,8 +23,8 @@ from os.path import join as pjoin
 import libcloud.security
 from cliff.app import App
 from cliff_rackspace.command_manager import CommandManager
+from cliff_rackspace.commands.help import HelpAction
 
-from service_registry_cli.commands.help import HelpAction
 from service_registry_cli import __version__
 
 CA_CERT_PATH = os.path.join(os.path.abspath(os.path.dirname(__file__)),
